      program dat2munk
c
C=======================================================================
C=         TRANSFORMATION DU FICHIER ASCII "Fm_UVWThRv.dat" EN FICHIER =
C=         A ACCES DIRECT LISIBLE PAR INTERPOLATION ET GRADS           =
C=======================================================================
c
c  Variables :
c  ----------
c   nl       : nombre de niveaux des donnees
c   nbhap    : nombre de pas de temps de la future simulation
c   u_hapex  : numero d'unite pour le fichier d'ecriture
c   z        : altitude aux interfaces
c   u        : vitesse zonale
c   v        : vitesse meridienne
c   Tpot     : Temperature potentielle
c   Q        : rapport de melange
c   P        : pression (grille initiale)
c   PH       : pression aux interfaces (variable au cours du temps)
c   out ...  : variables de sortie, exprimees en milieu de couche,
c              exceptee out_ph qui est la pression aux interfaces.
c
      integer klon,u_hapex
      parameter (klon=1,u_hapex=33)
      integer nl,nbhap
      parameter (nll=48,nbhap=40)
      integer icomp
      character*4 string 
      real z(nll),u(nll,nbhap),v(nll,nbhap)
     *    ,Tpot(nll,nbhap)
     *    ,temp(nll,nbhap),Q(nll,nbhap),s(nll,nbhap)
     *    ,p(nll),pp(nll,nbhap)
      real out_ps(nbhap),out_z(nll),out_u(nll,nbhap),out_v(nll,nbhap)
     *     ,out_temp(nll,nbhap),out_Q(nll,nbhap),out_pp(nll,nbhap)
     *     ,out_ph(nll,nbhap)
c
      character *1 s1
      character *2 s2
      character *3 s3
      character *4 s4
      character *5 s5
      character *6 s6
      character *7 s7
c
      open(22,file='Fm_UVWThRv.dat',form='formatted') ! profils
      open(23,file='Fm_AltRR.dat',form='formatted')   ! grille
c
c--    Read file 22 : nstep
c
      read (22,*) s5
      read (22,*) s5
      read (22,*) s5,s2,s1,s7,nstep
      print *, ' nbre de pas de temps : ',nstep
      IF (s1 .NE. 'I')  THEN
        print *,' mvs fichier 22 ; trouve ',s1,
     $          ' au lieu de I'
        stop
      ENDIF
c--    Read file 22 : temp, q, u, v
c
12    read(22,1000,end=90) string
      print *, string
      IF (string .ne. 'U(m/') go to 12
c
      call Fmread(22,u,nll,nstep)
c
13    read(22,1000,end=90) string
      print *, string
      IF (string .ne. 'V(m/') go to 13
c
      call Fmread(22,v,nll,nstep)
c
10    read(22,1000,end=90) string
1000  format (a4)
      print *, string
      IF (string .ne. 'Thet') go to 10
c
      call Fmread(22,Tpot,nll,nstep)
c
11    read(22,1000,end=90) string
      print *, string
      IF (string .ne. 'RV(g') go to 11
c
      call Fmread(22,Q,nll,nstep)
c
      print *, 'Nbre de pas de temps : ',nstep,'Nbre de niveaux : ',nll
c
      go to 100
90    print *, 'mauvais fichier 22'
      stop
c
100   continue
c
c          Vapour mixing ratio g/kg -> kg/kg
        do k=1,nll
          do it=1,nstep
            Q(k,it) = Q(k,it)/1000.
          enddo
        enddo
c
c--    Read file 23 : psol et zsol
      read(23,*) s1
      print *, s1
      read(23,*) s1
      print *, s1
      read(23,*) s1
      print *, s1
      read(23,*) s1
      print *, s1
      read(23,*) s2,s1,psol,s2
      print *, 'psol = ',psol,s2
      IF (s2 .NE. 'Pa') THEN
        print *,' mvs fichier 23 ; trouve : ',s2,
     $          ' au lieu de : Pa'
        stop
      ENDIF
c
c--    Read again file 23 : grille en z
30    backspace(23)
      backspace(23)
      read(23,1000,end=90) string
      print *, string
      IF (string .ne. 'Alti') go to 30
c
      call Fmread(23,z,nll,1)
c
c--    Compute grid level pressures
c
c      Les niveaux de grille sont aux interfaces entre couches. On part
c      de la surface (psol, zsol) et on remonte.
      Rg = 9.8
      Rd = 1000.0 * 1.380658E-23 * 6.0221367E+23 / 28.9644
      Cpd = 3.5 * Rd
      akapa = 2./7.
      ktop = 45   ! dernier niveau de la grille
      k1 = 2      ! premier niveau de la grille
      do it=1,nstep
        pp(k1,it) = psol
        pi = (pp(k1,it)/1.e5)**akapa
        Temp(k1,it) = pi*Tpot(k1,it)
        do k=k1,ktop-1
          coef = Rg*(z(k+1)-z(k))/
     $          (Rd*Temp(k,it)*(1.+Q(k,it)/0.622-Q(k,it)))
          deltap = - pp(k,it)*coef
ccc          print *,'k,Tpotav,coef,deltap ',k,Tpotav,coef,deltap
          pp(k+1,it) = pp(k,it)+deltap
          pi = (pp(k+1,it)/1.e5)**akapa
          Temp(k+1,it) = pi*Tpot(k+1,it)
        enddo
        print *,' psol, ptop ',pp(k1,it),pp(ktop,it)
      enddo
      print *,' Temp '
      print *, ((Temp(k,it),k=1,nll),it=1,nstep)
c
c
c--    Valeurs dans les couches et a la surface
c
c      Pour z, on prend l'origine a la surface
      nl = ktop - k1
      do k = 1,nl
         out_z(k) = 0.5*(z(k+1)+z(k+2)) - z(k1)
      enddo
      do it = 1,nstep
         out_ps(it) = pp(2,it)
         do k = 1,nl
            out_ph(k,it) = pp(k+1,it)
            out_pp(k,it) = 0.5*(pp(k+1,it) + pp(k+2,it))
            out_u(k,it) = 0.5*(u(k+1,it) + u(k+2,it))
            out_v(k,it) = 0.5*(v(k+1,it) + v(k+2,it))
            out_Temp(k,it) = 0.5*(Temp(k+1,it) + Temp(k+2,it))
            out_Q(k,it) = 0.5*(Q(k+1,it) + Q(k+2,it))
         enddo
      enddo
c
      open(u_hapex,file='hapex.dat',form='unformatted',
     .              access='direct',recl=klon*4)
            icomp=0
      do it=1,nstep
            icomp=icomp+1
            write(u_hapex,rec=icomp)out_ps(it)
         do k=1,nl
            icomp=icomp+1
            write(u_hapex,rec=icomp)(out_z(k))
         enddo
         do k=1,nl
            icomp=icomp+1
            write(u_hapex,rec=icomp)(out_u(k,it))
         enddo
         do k=1,nl
            icomp=icomp+1
            write(u_hapex,rec=icomp)(out_v(k,it))
         enddo
         do k=1,nl
            icomp=icomp+1
            write(u_hapex,rec=icomp)(out_Temp(k,it))
         enddo
         do k=1,nl
            icomp=icomp+1             
            write(u_hapex,rec=icomp)(out_Q(k,it))
         enddo
         do k=1,nl
            icomp=icomp+1 
            write(u_hapex,rec=icomp)(out_PP(k,it))
         enddo
         do k=1,nl
            icomp=icomp+1 
            write(u_hapex,rec=icomp)(out_PH(k,it))
         enddo
      enddo 
      close(u_hapex)
      open(99,file='hapexpp.ctl',form='formatted')
          write(99,'("DSET ^hapex.dat")')
          write(99,'("UNDEF 1.0E+30")')
          write(99,'("TITLE HAPEX92 case")')
          write(99,'("XDEF 1 LEVELS 0.0")')
          write(99,'("YDEF 1 LEVELS 0.0")')
          write(99,'("ZDEF",1x,i2,2x,"LEVELS",/(4f10.3))')
     .                     nl ,(out_pp(k,1)/100.,k=1,nl)
          write(99,'("TDEF",2x,i2,2x,"LINEAR",2x,
     .               "17:00Z26JUN1992  20MN")')
     .                nstep
          write(99,'("VARS        8")')
          write(99,'("Ps      ",2x,"0",2x,"99",2x,
     .               "Psol")')
          write(99,'("zz     ",2x,i3,2x,"99",2x,
     .               "altitude")')(nl)
          write(99,'("u      ",2x,i3,2x,"99",2x,
     .               "vitesse zonale")')nl
          write(99,'("v      ",2x,i3,2x,"99",2x,
     .               "vitesse meridienne")')nl
          write(99,'("Temp   ",2x,i3,2x,"99",2x,
     .               "temperature")')nl
          write(99,'("Q      ",2x,i3,2x,"99",2x,
     .               "humidite specifique")')nl
          write(99,'("P      ",2x,i3,2x,"99",2x,
     .               "pression (couches)")')nl
          write(99,'("PH     ",2x,i3,2x,"99",2x,
     .               "pression (interfaces)")')nl
          write(99,'("ENDVARS")')
      close(99)
c
      open(99,file='hapex.ctl',form='formatted')
          write(99,'("DSET ^hapex.dat")')
          write(99,'("UNDEF 1.0E+30")')
          write(99,'("TITLE HAPEX92 case")')
          write(99,'("XDEF 1 LEVELS 0.0")')
          write(99,'("YDEF 1 LEVELS 0.0")')
          write(99,'("ZDEF",1x,i2,2x,"LEVELS",/(4f10.3))')
     .                     nl ,(out_z(k),k=1,nl)
          write(99,'("TDEF",2x,i2,2x,"LINEAR",2x,
     .               "17:00Z26JUN1992  20MN")')
     .                nstep
          write(99,'("VARS        8")')
          write(99,'("Ps      ",2x,"0",2x,"99",2x,
     .               "Psol")')
          write(99,'("zz     ",2x,i3,2x,"99",2x,
     .               "altitude")')(nl)
          write(99,'("u      ",2x,i3,2x,"99",2x,
     .               "vitesse zonale")')nl
          write(99,'("v      ",2x,i3,2x,"99",2x,
     .               "vitesse meridienne")')nl
          write(99,'("Temp   ",2x,i3,2x,"99",2x,
     .               "temperature")')nl
          write(99,'("Q      ",2x,i3,2x,"99",2x,
     .               "humidite specifique")')nl
          write(99,'("P      ",2x,i3,2x,"99",2x,
     .               "pression (couches)")')nl
          write(99,'("PH     ",2x,i3,2x,"99",2x,
     .               "pression (interfaces)")')nl
          write(99,'("ENDVARS")')
      close(99)
                          
      print*,'hello'
      end 
      subroutine Fmread(iunit,x,nz,nt)
      dimension x(nz,nt)
c
      character*4 string
c
      i1 = 1
c
c      Boucle sur les rangees correspondant aux diverses tranches de
c      pas de temps
c ---------------------------------------------------------------------
10    continue
      do i=1,10
        read(iunit,1000) string
1000    format (a4)
        if (string .eq. '.***') go to 20
      enddo
      go to 90
c
20    continue
      i2 = min(nt,i1+4)
      do ik = 1,nz
          read(iunit,*) k,(x(k,i),i=i1,i2)
ccc          print *, k,(x(k,i),i=i1,i2)
      enddo
      if (i2 .ge. nt) go to 30
      i1 = i2+1
      go to 10
c --------------------fin de la boucle sur les rangees ----------------
c
30    continue
      print *, 'Nbre de pas de temps lus : ', i2
c
      return
c ====================================
c
90    print *, 'mauvais fichier ',iunit
      stop
c
      end

