      program qav2asci
c
C=========================================================================
C=       TRANSFORMATION DU FICHIER A ACCES DIRECT "tq.fwrite" EN FICHIERS  =
C=         ASCII "tq24.data", "tq25.data", "tq26.data", "tq27.data",       =
C=         contenant P, Theta et q aux instants 24, 25, 26, 27.            =
C=========================================================================
c
c  Variables :
c  ----------
c   nl       : nombre de niveaux des donnees
c   7        : nombre de pas de temps de la future simulation
c   u_eucrem : numero d'unite d'ecriture
c   z        : altitude
c   hTpot    : tendance de temperature potentielle
c   hQ       : tendance de rapport de melange
c   hw       : vitesse verticale
c   P        : pression
c
c   Parameters :
c   -----------
c   nl       : dimension de la grille
c   nbeuc    : nombre de pas de temps des donnees
c   ifrst    : nombre de duplicata du premier pas, ajoutes en tete
c
c----------------------------------------------------------------------
c Modifications :
c                        JYG (17/09/99)
c   Pas de temps du fichier de sortie fixe a la moitie de celui d'entree.
c   Un systeme lineaire est resolu de telle sorte que les valeurs moyennes
c   des diverses grandeurs sur chaque pas de temps soient les valeurs d'entree.
c     Le profil temporel des grandeurs est suppose constitue de segments de
c   droites dont les extremites sont aux milieux des pas de temps, sauf pour
c   le premier (qui part de 0) et le dernier (qui arrive en nbeuc).
c
c   Le systeme donnant les valeurs y aux milieux des pas de temps est
c   (en designant par mu_i la valeur moyenne (entree) sur le pas i) :
c             y_1 = mu_1
c             y_nbeuc = mu_nbeuc
c             6*y_i + y_(i-1) + y_(i+1) = 8*mu_i   (i = 2,nbeuc-1)
c
c   Les 2*nbeuc+1 valeurs z_i aux limites et milieux des pas sont donnees par :
c             z_1 = (3*y_1-y_2)/2
c             z_(2*nbeuc+1) = (3*y_nbeuc-y_(nbeuc-1))/2
c             z_2i = y_i                           (i = 2,nbeuc)
c             z_(2i+1) = (y_i+y_(i+1))/2           (i = 2,nbeuc-1)
c
c   Tous ces calculs sont faits dans le sous-programme av2inst.
c---------------------------------------------------------------------
c
      character*5 string
      integer klon,u_eucrem
      parameter (klon=1,u_eucrem=33)
      integer nl,nbeuc
      integer u_hapex,u_tq
      parameter (nll=100)
      parameter (ifrst = 0, ifrstp1 = ifrst+1)
      parameter (nl=43,nbeuc=1,nbeucpf=nbeuc+ifrst,nbeuc2=2*nbeuc+1)
      parameter (nlFm=48)        ! dimensions dans le fichier de forcage
      integer icomp
      real htpot_fm(nlFm,nbeuc),hQ_fm(nlFm,nbeuc)
     *    ,hw_fm(nlFm,nbeuc)
     *    ,hThTur_fm(nlFm,nbeuc),hqTur_fm(nlFm,nbeuc)
     *    ,Q1_fm(nlFm,nbeuc), Q2_fm(nlFm,nbeuc)
      real z(nl),htpot(nl,nbeucpf),hQ(nl,nbeucpf)
     *    ,hThTur(nl,nbeucpf),hqTur(nl,nbeucpf)
     $    ,hw(nl,nbeucpf),p(nl),hU(nl,nbeucpf),hV(nl,nbeucpf)
     *    ,Q1(nl,nbeuc), Q2(nl,nbeuc)
      real theta(nl), qv(nl)
      real SQ1(nbeucpf), SQ2(nbeucpf)
      real Sht(nbeucpf), Shq(nbeucpf)
      real hTpot2(nl,nbeuc2),hQ2(nl,nbeuc2)
     *    ,hThTur2(nl,nbeuc2),hqTur2(nl,nbeuc2)
     $    ,hw2(nl,nbeuc2),hU2(nl,nbeuc2),hV2(nl,nbeuc2)
     *    ,Q12(nl,nbeuc2), Q22(nl,nbeuc2)
      real SQ12(nbeuc2), SQ22(nbeuc2)
      real Sht2(nbeuc2), Shq2(nbeuc2)
      real yy(nl,nbeucpf)
      real ps(nbeuc),zz(nl,nbeuc),u(nl,nbeuc),v(nl,nbeuc)
     $    ,Temp(nl,nbeuc),Q(nl,nbeuc),PP(nl,nbeuc),PH(nl,nbeuc)
c
      character*5 string_tur
      data string_tur/'q-Tur'/
c
      character *5 s1
      character *2 s2
      character *1 s3
      character *7 s4
c
c
c--    Lecture et ecriture de P, Theta, qv
c
       icomp=0
      u_tq = 21
      open(u_tq,file='tq.fwrite',form='unformatted',
     .              access='direct',recl=4)
c
       call rdgrads2(u_tq,icomp,nl,p,theta,qv)
       print *,' Lecture : instant 24'
      open(22,file='tq24.data',form='formatted')
      do k = 1,nl
       write (22,*) p(k),theta(k),qv(k)
      enddo
      close (22)
c
       call rdgrads2(u_tq,icomp,nl,p,theta,qv)
       print *,' Lecture : instant 25'
      open(22,file='tq25.data',form='formatted')
      do k = 1,nl
       write (22,*) p(k),theta(k),qv(k)
      enddo
      close (22)
c
       call rdgrads2(u_tq,icomp,nl,p,theta,qv)
       print *,' Lecture : instant 26'
      open(22,file='tq26.data',form='formatted')
      do k = 1,nl
       write (22,*) p(k),theta(k),qv(k)
      enddo
      close (22)
c
       call rdgrads2(u_tq,icomp,nl,p,theta,qv)
       print *,' Lecture : instant 27'
      open(22,file='tq27.data',form='formatted')
      do k = 1,nl
       write (22,*) p(k),theta(k),qv(k)
      enddo
       print *,' Instant 27 ecrit sur tq27.data'
      close (22)
c
      stop
      end
      SUBROUTINE rdgrads1(itape,icompt,nl,ps,z,u,v,temp,q,p,ph)


      IMPLICIT none
      integer nl
      INTEGER itape
c
      real ps
      real p(nl),u(nl),v(nl),z(nl),q(nl),temp(nl),ph(nl)

c
      INTEGER i, k
c
      INTEGER icompt
c
      print *, 'nl ',nl
c
            icompt=icompt+1
            READ(itape,rec=icompt)ps
         do k=1,nl
            icompt=icompt+1
            READ(itape,rec=icompt)z(k)
         enddo
         do k=1,nl
            icompt=icompt+1
            READ(itape,rec=icompt)u(k)
         enddo
         do k=1,nl
            icompt=icompt+1
            READ(itape,rec=icompt)v(k)
         enddo
         do k=1,nl
            icompt=icompt+1
            READ(itape,rec=icompt)Temp(k)
         enddo
         do k=1,nl
            icompt=icompt+1             
            READ(itape,rec=icompt)Q(k)
          if (q(k).le.0. ) q(k)=1.e-06
         enddo
         do k=1,nl
            icompt=icompt+1 
            READ(itape,rec=icompt)P(k)
         enddo
         do k=1,nl
            icompt=icompt+1 
            READ(itape,rec=icompt)PH(k)
         enddo

c
c
      RETURN
      END
      SUBROUTINE rdgrads2(itape,icompt,nl,z,q1,q2)


      IMPLICIT none
      integer nl
      INTEGER itape
c
      real z(nl),q1(nl),q2(nl)

c
      INTEGER i, k
c
      INTEGER icompt
c
      print *, 'nl ',nl
c
         do k=1,nl
            icompt=icompt+1
            READ(itape,rec=icompt)z(k)
            print *,' z ',k,z(k)
         enddo
         do k=1,nl
            icompt=icompt+1
            READ(itape,rec=icompt)q1(k)
            print *,' q1 ',k,q1(k)
         enddo
         do k=1,nl
            icompt=icompt+1
            READ(itape,rec=icompt)q2(k)
            print *,' q2 ',k,q2(k)
         enddo
c
c
c
      RETURN
      END

