      PROGRAM interpolation
c
c 
      IMPLICIT NONE
c
#include "interpcom_hapex.h"
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     Ce programme d'interpolation laisse le GCM avec ses 11 niveaux
c     mais interpole les valeurs des variables tempz,ovapz et qlz du
c     Meso-NH (sur 53 niveaux) pour donner des valeurs de tempg,ovapg 
c     et qlg du GCM a ses propres niveaux (variables qui sont respecti-
c     vement la temperature,la vapeur d'eau et l'eau liquide).
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c       
      REAL val     !valeur intermediaire dans l'interpolation       
      INTEGER i
      INTEGER lu
      INTEGER k
      INTEGER mlz
      INTEGER mlzh
      INTEGER j
 
c
c     teta=tempz((po/p)**RKAPPA) avec RKAPPA=Rd/Cpd , p pression 
c     Meso-NH , et po pression au sol (1000. hPa).
c   
      print*,' '
cc      Attention : On lira dans lect_ini_meso les pressions dans ca3a.dat ;
cc      elles sont coherentes avec psol (lue aussi dans ca3a.dat). Cet appel
cc      a meso_lupress sert seulement a initialiser nblvlm.
      call meso_lupress
      print*,' '
c
      call meso_ludat     !a modifier en fonction de chaque cas
      print*,' '
c
      call lect_ini_meso  !a modifier en fonction de chaque cas
      print*,' '
ccc      psolpa = 96840.    !a modifier en fonction de chaque cas
      if (psol .gt. 10000.) then
        psolpa = psol
        psol = psol/100.
      else
        psolpa = psol*100.
      endif
c
      call gcm_lupress 
      print*,' '
      call def_surf      !a modifier en fonction de chaque cas
      print *,' '
c
      call corres_gcm_meso
      print*,' '
c
      call calcul_ini_gcm !a modifier en fonction de chaque cas
c
      call ecrit_surf
c
      end
c
c----------------------------------------------------------------------------
      subroutine meso_lupress
c
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     Cette subroutine lit dans le fichier de controle "ca3a.ctl"
c     et affiche le nombre de niveaux du Meso-NH ainsi que les valeurs
c     des pressions en milieu de couche du Meso-NH (en Pa puis en hPa).
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
      IMPLICIT NONE
c
#include "interpcom_hapex.h"
c
      REAL val
      REAL plim
      REAL ak
      INTEGER i
      INTEGER lu
      INTEGER k
      INTEGER mlz
      INTEGER mlzh
      INTEGER j
c
      INTEGER u_hapex,icomp
      REAL meso_ps, meso_z(50),meso_u(50),meso_v(50),meso_temp(50)
      REAL meso_Q(50),meso_PP(50),meso_PH(50)
c
      character*4 a
c
      lu=9
      open (lu,file='hapex.ctl')
c
      do i=1,1000
      read(lu,1000,end=999) a
      if (a .eq. 'ZDEF') go to 100
      enddo
c
 100  backspace(lu)
      print*,'  DESCRIPTION DES 2 MODELES : '
      print*,' '
      read(lu,1001) nblvlm
      print*,'nbre de niveaux de pression Meso-NH :',nblvlm
      print*,' '
      print*,'pression en Pa de chaque couche du meso-NH :'  
c
ccc      read(lu,*) (playm(mlz),mlz=1,nblvlm)
c
c      Lecture du fichier a acces direct et extraction de la pression
c
c
      u_hapex = 21
      open(u_hapex,file='hapex.dat',form='unformatted',
     .              access='direct',recl=klon*4)
       icomp=0
       call rdgrads(u_hapex,icomp,nblvlm,meso_ps,meso_z,
     $          meso_u,meso_v,meso_Temp,meso_Q,meso_PP,meso_PH)
       do k= 1,nblvlm
         playm(k) = meso_PP(k)
       enddo
c
      close(u_hapex)
c--------------------------------------------------------------------
c
c      Si la pression est en HPa, la multiplier par 100
      if (playm(1) .lt. 10000.) then
        do mlz = 1,nblvlm
         playm(mlz) = playm(mlz)*100.
        enddo
      endif
      print*,(playm(mlz),mlz=1,nblvlm)
c
 1000 format (a4)
 1001 format(5x,i2)
c 
      print*,' '
      do mlzh=1,nblvlm
      hplaym(mlzh)=playm(mlzh)/100.
      enddo
c
      print*,'pression en hPa de chaque couche du meso-NH: '
      print*,(hplaym(mlzh),mlzh=1,nblvlm)
c
      return
c
 999  stop 'erreur lecture des niveaux pression des donnees'
      end
c
c----------------------------------------------------------------------------
      subroutine meso_ludat
c
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     Cette subroutine fixe la date du premier jour des donnees et 
c     l'increment temporel.
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
      IMPLICIT NONE
c
#include "interpcom_hapex.h"
c
      REAL val
      REAL plim
      REAL ak
      INTEGER i
      INTEGER lu
      INTEGER k
      INTEGER mlz
      INTEGER mlzh
      INTEGER j
c
      heure_zero = 17
      jour_zero = 26
      mois_zero = 06
      ian_zero = 1992
      step = 20.*60.   ! en secondes
      print*,' DATE DU 1ER JOUR DES DONNEES : '
      print *, heure_zero, jour_zero, mois_zero, ian_zero
      print*,' '
      print *,' time step (s) : ',step
c
      return
c
      end
c
c----------------------------------------------------------------------------
c     lecture de l'etat initial (IN) du modele Meso-NH 
c
      subroutine lect_ini_meso
c
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     Cette subroutine lit dans "ca3a.dat" les valeurs des
c     variables d'etat definissant le profil vertical de
c     l'environnement,et les affiche.
c     De plus,elle ecrit dans "cchlim.data" les valeurs
c     de la vitesse du vent a cet instant initial,qui sont imposees.
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c 
      IMPLICIT NONE
c
#include "interpcom_hapex.h"
c
      INTEGER LZ
      REAL RKAPPA
      PARAMETER(LZ=43)
cFKC      PARAMETER(LZ=70)
      PARAMETER (RKAPPA=.2857143E+00)
c
cc      REAL TSURF      ! 0  99 temperature de surface          (K)
cc      REAL QGSURF     ! 0  99 vapeur d'eau en surface     (kg/kg)
cc      REAL FLUT0      ! 0  99 flux chaleur sensible (K.kg/(s.m2))
cc      REAL FLUG0      ! 0  99 flux vapeur d'eau       (kg/(s.m2))
cc      REAL PRECIP     ! 0  99 taux de precipitations   (kg/(s.m2))
cc      REAL FLUU0      ! 0  99 flux u                   (kg/(s2.m))
cc      REAL FLUV0      ! 0  99 flux v                   (kg/(s2.m))
cc      REAL FLUW0      ! 0  99 flux w                   (kg/(s2.m))
c      REAL zz(LZ)       ! 43  99  altitude
      REAL PP(LZ)       ! 43  99  pression en milieu de couche
      REAL PH(LZ)       ! 43 99   pression aux interfaces

cc      REAL CVGTZ(LZ)  ! 53  99 grande echelle equ. TEMPZ      (K/s)
cc      REAL CVGGZ(LZ)  ! 53  99 grande echelle equ. OVAPZ((kg/kg)/s)
cc      REAL CVGUZ(LZ)  ! 53  99 grande echelle equ. UZ        (m/s2)
cc      REAL CVGVZ(LZ)  ! 53  99 grande echelle equ. VZ        (m/s2)
cc      REAL CVGWZ(LZ)  ! 53  99 grande echelle equ. WZ        (m/s2)
cc      REAL Q1Z(LZ)    ! 53  99 source apparente chaleur Q1    (K/s)
cc      REAL Q2Z(LZ)    ! 53  99 puits apparente d'humidite Q2  (K/s)
cc      REAL QRADZ(LZ)  ! 53  99 effets radiatifs Qr            (K/s)
cc      REAL QUZ(LZ)    ! 53  99 transfert qte mvt/x        Qu (m/s2)
cc      REAL QVZ(LZ)    ! 53  99 transfert qte mvt/y        Qv (m/s2)
cc      REAL ONUAGZ(LZ) ! 53  99 contenu specif. eau nuageuse  (kg/kg)
cc      REAL ORAINZ(LZ) ! 53  99 contenu specif. eau precipit. (kg/kg)
cc      REAL PSZ(LZ)    ! 53  99 fraction nuageuse                 (%)
      INTEGER ICOUNT, L, itape
      INTEGER m,i,k,mlz,mlzh
      INTEGER id,iyyy,mm,heure  !arguments de date_step
      CHARACTER*3 w         !     "            "
c
*
      print*,'        INSTANT INITIAL DU MESO-NH : ' 
      print*,' '
      print*,'instant initial entier entre 1 et 33:'
      read*,IN
      print *, IN
      print*,' '
      call date_step(in,id,mm,iyyy,w,heure,heure_zero
     $              ,jour_zero,mois_zero,ian_zero,step)
       print*,'la date est:',heure,' ',id,w,iyyy
      ddat(1)=heure
        print*,'heure',ddat(1)
      ddat(2)=id
      ddat(3)=iyyy
      sdat=w
       print*,'sdat',sdat
c
      OPEN(99,FILE='hapex.dat',FORM='UNFORMATTED',
     .     ACCESS='DIRECT',RECL=4)

c
      ICOUNT = (IN-1)*(1+nblvlm*7)
      print *, 'icount ',icount
*

      itape=99
      call rdgrads(itape,ICOUNT,nblvlm,psol,zz,uz,vz,tempz,ovapz,pp,ph)
c
c
 2    format(7f10.6)
c
      close(77)
c 
      CLOSE(99)
c
      print*,'TEMP0 : ',tempz
      print*,' '
      print*,'OVAPZ0 : ',ovapz
      print*,' '
c       
      print*, ' UZ',UZ
      print*, 'VZ ',VZ
c
c      Copier pp dans playm
        do mlz = 1,nblvlm
         playm(mlz) = pp(mlz)
        enddo
c      Si la pression est en HPa, la multiplier par 100
      if (playm(1) .lt. 10000.) then
        do mlz = 1,nblvlm
         playm(mlz) = playm(mlz)*100.
        enddo
      endif
      print*,(playm(mlz),mlz=1,nblvlm)
c
 1000 format (a4)
 1001 format(5x,i2)
c 
      print*,' '
      do mlzh=1,nblvlm
      hplaym(mlzh)=playm(mlzh)/100.
      enddo
c
      print*,'pression en hPa de chaque couche du meso-NH: '
      print*,(hplaym(mlzh),mlzh=1,nblvlm)
 
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     passage de la temperature potentielle a la temperature
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccc      do m=1,nblvlm
ccc      tempz(m)=tetaz(m)*((hplaym(m)/1000.)**RKAPPA)
ccc      enddo
c
      print*,'  '
      print*,'temperature initiale du Meso-NH par niveau :',tempz
c
      RETURN 
      END
c
c----------------------------------------------------------------------------
      subroutine gcm_lupress
c
c
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     Cette subroutine lit dans le fichier de controle "histoire_int.ctl"
c     et affiche le nombre de niveaux du GCM ainsi que les valeurs
c     des pressions en milieu de couche du GCM (en hPa).
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
      IMPLICIT NONE
c
#include "interpcom_hapex.h"
c
      REAL val
      REAL plim
      REAL ak
      REAL fact
      INTEGER i
      INTEGER lu
      INTEGER k
      INTEGER mlz
      INTEGER mlzh
      INTEGER j
c
      character*4 a
c
      lu=8
      open (lu,file='histoire_int.ctl')
c
      do i=1,1000
      read(lu,1000,end=888) a
      if (a .eq. 'ZDEF') go to 100
      enddo
c
      go to 888
c
 100  backspace(lu)
      read(lu,1001) klev
c   Le nbre de niveaux dans histoire_int est klev+1 (il s'agit des
c   limites entre couches et non des milieux de couche).
      klev = klev-1
      print *,'nbre de niveaux de pression GCM:', klev
      print*,' '
c
      read(lu,*) (paprs(k),k=1,klev+1)
c
cc       homotetie sur les pressions amenant paprs(1) a psol
cc        (du coup les pressiosn sont en unites de psol, i.e. en hPa)
      fact = psol/paprs(1)
      do k = 1,klev
         paprs(k) = paprs(k)*fact
      enddo
c
      do k=1,klev
         play(k) = (paprs(k)+paprs(k+1))/2.
      enddo
c
c      conversion en HPa si necessaire
c
cc      print*,'pression en Pa de chaque couche du GCM : '
cc      print*, (play(k),k=1,klev)
cc      if (play(1).gt.10000.) then
cc        do k=1,klev 
cc        play(k)=play(k)/100. 
cc        enddo
cc      endif
cc      if (paprs(1).gt.10000.) then
cc        do k=1,klev
cc        paprs(k)=paprs(k)/100.
cc        enddo
cc      endif
      print*,'pression en hPa de chaque couche du GCM : '
      print*, (play(k),k=1,klev)
c
 1000 format(a4)
 1001 format(5x,i2)
      return
c
 888  stop 'erreur lecture des niveaux pression du GCM'
      end
c
c----------------------------------------------------------------------------
      subroutine def_surf
c
c       Definition des conditions de surface
c       ------------------------------------------------
c
#include "interpcom_hapex.h"
c
c
c
      DO i = 1, klon 
cfkc terre hapex        lmt_nat(i) = 0.
c cas terre        lmt_nat(i) = 1.
c ocean ou terre avec tsol cst
        lmt_nat(i) = 1.
        beta(i) = 0.95 !rapport entre l'evaporation reelle et
c                      !l'evapotranspiration 
        cal(i) = 0.15  !Cp/cal indique la capacite calorifique surfacique
c                      !du sol
        rugsol(i) = 0.05  ! rugsol pour le continent
       IF (NINT(lmt_nat(i)) .EQ. 0) THEN
        beta(i) = 1.0
cfkc cas continent pas de modele de sol
        beta(i) = 0.80
        cal(i) = 0.0   !(1/capa.calor.de l'ocean) tend vers 0
        rugsol(i) = 0.0001
cfkc cas continent pas de modele de sol
        rugsol(i) = 0.05  ! rugsol pour le continent
       ENDIF
       dif_grnd(i) = 0.0 !coef. de diffusion avec l'ocean profond
       coefh(i,1) = 0.0015 !coefficient de friction
      ENDDO
c       Temperature
chapex 1
c      tsol =  299.75
      tsol=301.2
chapex 5
c      tsol =  306.95
ccopt81
c       tsol=303.2 ! attention pour simul radiative and surface process OFF
c      
c
c       Humidite
chapex 1
      qsol = .0173
chapex5 
c      qsol = .0162
c
cCOPT81 
c      qsol = .0180
      return
      end
c----------------------------------------------------------------------
      subroutine ecrit_surf
c
c       Ecriture des conditions de surface
c       ------------------------------------------------
c
#include "interpcom_hapex.h"
c
      open (22,file='condsurf.data')
c
c       Pression au sol
      write (22,*) psolpa
c
c       Temperature
      write (22,*) tsol
c
c       Humidite
      write (22,*) qsol
c
      close (22)
c
      open (77,file='cchlim.data',form='formatted')
      write(77,2) beta
      write(77,2) cal
      write(77,2) dif_grnd
      write(77,2) rugsol
      write(77,2) coefh
 2    format(7f10.6)
      close (77)
c
      return
      end
c
c-----------------------------------------------------------------------
      subroutine corres_gcm_meso
c
c
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     Cette subroutine calcule et affiche les valeurs des coefficients
c     d'interpolation qui serviront dans la formule d'interpolation elle-
c     meme.
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c 
      IMPLICIT NONE
c
#include "interpcom_hapex.h"
c
      REAL val,fact
      REAL plim
      REAL ak
      INTEGER i
      INTEGER lu
      INTEGER k
      INTEGER mlz
      INTEGER mlzh
      INTEGER j
c
c        Calage de psol; transformation des niveaux de pression du
c        GCM de telle sorte que sigma soit conservee.
cc      fact = psol/paprs(1)
cc      do k = 1,klev
cc        play(k) = play(k)*fact
cc      enddo
cc      do k = 1,klev+1
cc        paprs(k) = paprs(k)*fact
cc      enddo
c
c        Sortie en erreur si la pression n'est pas decroissante;
c
c        1/ GCM
      if (play(1) .ge. psol) go to 888
      do k = 2,klev
         if (play(k) .ge. play(k-1)) go to 888
      enddo
c
c        2/ Meso
      print *,hplaym(1) , psol
      if (hplaym(1) .ge. psol) go to 889
      do k = 2,nblvlm
         if (hplaym(k) .ge. hplaym(k-1)) go to 889
      enddo
c
      lu=1
c 
c
c 
cjyg
c        Correction (16/11/97) : prise en compte des niveaux gcm situes
c        plus bas que le premier niveau meso-NH.
c
      do k=1,klev
         val=play(k)
       if (val .gt. hplaym(1)) then
          mlz = 0
          JM(k) = mlz
cjyg
cc          Correction (08/01/2001)
cc          Dans la premiere couche meso-NH, on prend des variables uniformes
            coef1(k) = 0.
            coef2(k) = 1.
cc
cc          coef1(1)=(hplaym(mlz+1)-val)
cc     *             /(hplaym(mlz+1)-psol)
cc          coef2(1)=(val-psol)
cc     *             /(hplaym(mlz+1)-psol)
       else
         do mlz=1,nblvlm-1
          if (     val .le. hplaym(mlz)
     *       .and. val .gt. hplaym(mlz+1))then
           JM(k)=mlz
           coef1(k)=(hplaym(mlz+1)-val)
     *              /(hplaym(mlz+1)-hplaym(mlz))
           coef2(k)=(val-hplaym(mlz))
     *              /(hplaym(mlz+1)-hplaym(mlz))
          endif
         enddo
c
         if (val .le. hplaym(nblvlm)) then
c       Pour les niveaux du GCM situes plus haut que le dernier niveau 
c      Meso, on prend T,q csts avec l'altitude
          mlz = nblvlm-1
          JM(k) = mlz
          coef1(k) = 0.
          coef2(k) = 1.
         endif
c
       endif
      enddo
c
cc      if (play(klev) .le. hplaym(nblvlm)) then
cc         mlz=nblvlm-1
cc         JM(klev)=mlz
cc         coef1(klev)=(hplaym(mlz+1)-val)
cc     *            /(hplaym(mlz+1)-hplaym(mlz))
cc         coef2(klev)=(val-hplaym(mlz))
cc     *            /(hplaym(mlz+1)-hplaym(mlz))
cc      endif
c
      print*,' '
      print*,'         INTERPOLATION  : '
      print*,' '
      print*,'correspondance de ',klev,' niveaux du GCM sur les',
     $       nblvlm,' du meso-NH:'
      print*,(JM(k),k=1,klev)
      print*,' '
      print*,'valeurs du premier coef d"interpolation pour les',
     $       klev,' niveaux : '  
      print*,(coef1(k),k=1,klev)
      print*,' '
      print*,'valeurs du deuxieme coef d"interpolation pour les',
     $       klev,' niveaux : '  
      print*,(coef2(k),k=1,klev)
c
      return
c
888   print *,' pressions non decroissantes pour le GCM'
      stop
889   print *,' pressions non decroissantes pour Meso'
      stop
      end
c
c----------------------------------------------------------------------------
c     calcul de l'etat initial du GCM
c     a l'instant IN du meso-NH 
c
      subroutine calcul_ini_gcm
c
c
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     Cette subroutine calcule,par interpolation,l'etat initial 
c     du GCM correspondant a l'instant initial choisi,et l'affiche.
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc   
c
      IMPLICIT NONE
c
#include "interpcom_hapex.h"
c
      INTEGER i,k,lu
      INTEGER ncst_cbmf
      REAL ema_pcb
c
      REAL qlsol,uzsol,vzsol,zzsol
      parameter (zzsol=0.0)
c
      do i=1,klev
       if (JM(i) .gt. 0) then
         zzg(i)=(coef1(i)*zz(JM(i)))
     *             +(coef2(i)*zz(JM(i)+1))
       else
         zzg(i)=(coef1(i)*zzsol)
     *             +(coef2(i)*zz(1))
       endif
      enddo
c
         print*,'l altitude est :',zzg

c
      do i=1,klev
       if (JM(i) .eq. 0) then
        tempg(i) = coef1(i)*tsol+coef2(i)*tempz(JM(i)+1)
       else
        tempg(i)=(coef1(i)*tempz(JM(i)))
     *           +(coef2(i)*tempz(JM(i)+1))
       endif
      enddo
c
c
      print*,'        INSTANT INITIAL DU GCM : '
      print *, ddat(1),'h, ',ddat(2),' ',sdat,' ',ddat(3)
c
c
      print*,' ' 
      print*,'temperature initiale GCM par niveau:',tempg
c
      do i=1,klev
       if (JM(i) .eq. 0) then
        ovapg(i)=(coef1(i)*qsol)
     *            +(coef2(i)*ovapz(JM(i)+1))
       else
        ovapg(i)=(coef1(i)*ovapz(JM(i)))
     *            +(coef2(i)*ovapz(JM(i)+1))
       endif
      enddo
c
      print*,' '
      print*,'vapeur d''eau initiale GCM par niveau:',ovapg
c
      do i=1,klev
       if (JM(i) .eq. 0) then
         qlg(i) = qlz(1)
       else
        qlg(i)=(coef1(i)*qlz(JM(i)))
     *          +(coef2(i)*qlz(JM(i)+1))
       endif
      enddo
c
      print*,' '
      print*,'contenu en eau liquide GCM par niveau:',qlg
c
c    valeurs initiales nulles pour sigma et w et pour ema_cbmf.
      do i=1,klev
         ema_sig(i) = 0.
         ema_w(i) = 0.
      enddo
      ncst_cbmf = 0  ! nbre de steps a cbmf fixe
      ema_cbmf = 0.
      ema_pcb = 0.   ! niveau de la base des nuages
c
c    valeurs initiales pour le modele de poche froide
      lu=25
      open (lu,file='iniwake.data',form='formatted')
      read (lu,*) (wake_dt(i),i=1,klev)
      read (lu,*) (wake_dq(i),i=1,klev)
      read (lu,*) wake_h
      read (lu,*) wake_k
      read (lu,*) wake_s
      read (lu,*) wake_pe
      read (lu,*) wake_fip
      close (lu)
c
      uzsol = 0.
      vzsol = 0.
      do i=1,klev
       if (JM(i) .gt. 0) then
         ug(i)=(coef1(i)*uz(JM(i)))
     *              +(coef2(i)*uz(JM(i)+1))
         vg(i)=(coef1(i)*vz(JM(i)))
     *              +(coef2(i)*vz(JM(i)+1))
       else
         ug(i)=(coef1(i)*uzsol)
     *              +(coef2(i)*uz(1))
         vg(i)=(coef1(i)*vzsol)
     *              +(coef2(i)*vz(1))
       endif
      enddo
c
      print*,' '
      print*,'vitesse zonale, par niveaux :',ug
      print*,'vitesse meridienne, par niveaux :',vg
c
      print*,'heure2',ddat(1)
c
      IF (klev .eq. 18) then
        open(98,file='startg18.data',form='formatted')
c       
      ELSE IF (klev .eq. 21) then
        open(98,file='startg21.data',form='formatted')
c
      ELSE
        open(98,file='startg.data',form='formatted')
c
      ENDIF
c
      write(98,*)(in)
cfkc      write(98,*)'200'         !3jours
      write(98,*)'43'         !3jours
      write(98,*)(play(k),k=1,klev)
      write(98,*)(paprs(k),k=1,klev+1)
c   etat initial
      write(98,*)(tempg(k),k=1,klev)
      write(98,*)(ovapg(k),k=1,klev)
      write(98,*)(qlg(k),k=1,klev)
      write(98,*)(ema_sig(k),k=1,klev)
      write(98,*)(ema_w(k),k=1,klev)
      write(98,*) ncst_cbmf,ema_cbmf,ema_pcb
c
      write(98,*)(zzg(k),k=1,klev)
      write(98,*)(ug(k),k=1,klev)
      write(98,*)(vg(k),k=1,klev)
      write(98,*)(wake_dt(k),k=1,klev)
      write(98,*)(wake_dq(k),k=1,klev)
      write(98,*) wake_h
      write(98,*) wake_k
      write(98,*) wake_s
      write(98,*) wake_pe
      write(98,*) wake_fip
      write(98,*)(ddat(1))
      write(98,*)(ddat(2))
      write(98,*)(ddat(3))
      write(98,*)(sdat)
      close(98)
c 
      return   
      end

